@@ -3,9 +3,26 @@
 # If you want to add a Browser to extend AWStats database detection capabilities,
 # you must add an entry in BrowsersSearchIDOrder and in BrowsersHashIDLib.
 #-------------------------------------------------------
-# $Revision: 1.49 $ - $Author: eldy $ - $Date: 2005/12/20 12:43:51 $
+# $Revision: 1.54 $ - $Author: eldy $ - $Date: 2006/09/14 22:22:12 $
 
+# 2006-05-15 Sean Carlos http://www.antezeta.com/awstats.html 
+# 				akregator (rss)
+#				AppleSyndication  (rss)
+#				BlogBridge http://www.blogbridge.com/ (rss)
+#				BonEcho (Firefox 2.0 alpha)
+#				FeedTools http://sporkmonger.com/projects/feedtools/ (rss)
+#				gnome\-vfs.*neon http://www.webdav.org/neon/
+#				GreatNews  http://www.curiostudio.com/ (rss)
+#				Gregarius devlog.gregarius.net/docs/ua (rss)
+#				hatena rss http://r.hatena.ne.jp/ (rss)
+#				Liferea http://liferea.sourceforge.net/ (rss)
+#				lilina http://lilina.sourceforge.net/ (rss)
+#				PubSub-RSS-Reader http://www.pubsub.com/ (rss)
+# 2006-05-20 Sean Carlos http://www.antezeta.com/awstats.html
+#				Potu Rss-Reader http://www.potu.com/
+#				OSSProxy http://www.marketscore.com/FAQ.Aspx
 
+#				
 #package AWSUA;
 
 
@@ -31,12 +48,15 @@
 'amaya',
 'amigavoyager',
 'aweb',
+'bonecho',
 'bpftp',
 'camino',
 'chimera',
 'cyberdog',
 'dillo',
+'doris',
 'dreamcast',
+'xbox',
 'downloadagent',
 'ecatch',
 'emailsiphon',
@@ -45,12 +65,15 @@
 'friendlyspider',
 'fresco',
 'galeon',
+'flashget',
+'freshdownload',
 'getright',
+'leechget',
+'netants',
 'headdump',
 'hotjava',
 'ibrowse',
 'intergo',
-'javaws',
 'k\-meleon',
 'linemodebrowser',
 'lotus\-notes',
@@ -84,30 +107,49 @@
 'jetaudio',
 'mint_audio',
 'mpg123',
+'mplayer',
 'nsplayer',
+'qts',
 'sonique',
 'uplayer',
-'xmms',
 'xaudio',
+'xine',
+'xmms',
 # RSS Readers
-'aggrevator', 
+'abilon',
+'aggrevator',
+'akregator',
+'applesyndication',
+'betanews_reader',
+'blogbridge',
 'feeddemon', 
 'feedreader', 
-'jetbrains_omea_reader', 
+'feedtools',
+'greatnews',
+'gregarius',
+'hatena_rss', 
+'jetbrains_omea', 
+'liferea',
+'lilina',
 'netnewswire', 
 'newsfire', 
 'newsgator', 
 'newzcrawler',
 'pluck', 
+'potu_rss\-reader',
+'pubsub\-rss\-reader',
 'pulpfiction', 
 'rssbandit', 
 'rssreader',
 'rssowl', 
+'rss\sxpress',
+'rssxpress',
 'sage', 
 'sharpreader', 
 'shrook', 
 'straw', 
 'syndirella', 
+'wizz\srss\snews\sreader',
 # PDA/Phonecell browsers
 'alcatel',				# Alcatel
 'lg\-',					# LG
@@ -120,7 +162,7 @@
 'sie\-',				# SIE
 'sec\-',				# SonyEricsson
 'sonyericsson',			# SonyEricsson
-'ericsson',				# Ericsson (must be after sonyericsson
+'ericsson',				# Ericsson (must be after sonyericsson)
 'mmef',
 'mspie',
 'wapalizer',
@@ -132,17 +174,37 @@
 'portalmmm',
 # Others (TV)
 'webtv',
+# Anonymous Proxy Browsers (can be used as grabbers as well...)
+'cjb\.net',
+'ossproxy',
 # Other kind of browsers
 'apt',
+'analogx_proxy',
+'gnome\-vfs',
+'neon',
 'curl',
 'csscheck',
+'httrack',
+'fdm',
+'javaws',
 'wget',
+'chilkat',
+'webdownloader\sfor\sx',
 'w3m',
 'wdg_validator',
+'webreaper',
 'webzip',
 'staroffice',
+'gnus', 
+'nikto', 
+'microsoft\-webdav\-miniredir', 
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery',
+'POE\-Component\-Client\-HTTP',
 'mozilla',				# Must be at end because a lot of browsers contains mozilla in string
-'libwww'				# Must be at end because some browser have both 'browser id' and 'libwww'
+'libwww',				# Must be at end because some browser have both 'browser id' and 'libwww'
+'lwp'
 );
 
 # BrowsersHashIDLib
@@ -153,6 +215,7 @@
 'msie','MS Internet Explorer',
 'netscape','Netscape',
 'firefox','Firefox',
+'svn', 'Subversion client', 
 
 'firebird','Firebird (Old Firefox)',
 'go!zilla','Go!Zilla',
@@ -168,12 +231,15 @@
 'amaya','Amaya',
 'amigavoyager','AmigaVoyager',
 'aweb','AWeb',
+'bonecho','<a href="http://www.mozilla.org/projects/bonecho/" title="Browser home page [new window]" target="_blank">BonEcho (Firefox 2.0 development)</a>',
 'bpftp','BPFTP',
 'camino','Camino',
 'chimera','Chimera (Old Camino)',
 'cyberdog','Cyberdog',
 'dillo','Dillo',
+'doris','Doris (for Symbian)',
 'dreamcast','Dreamcast',
+'xbox', 'XBoX',
 'downloadagent','DownloadAgent',
 'ecatch', 'eCatch',
 'emailsiphon','EmailSiphon',
@@ -182,7 +248,11 @@
 'friendlyspider','FriendlySpider',
 'fresco','ANT Fresco',
 'galeon','Galeon',
+'flashget','FlashGet',
+'freshdownload','FreshDownload',
 'getright','GetRight',
+'leechget','LeechGet',
+'netants','NetAnts',
 'headdump','HeadDump',
 'hotjava','Sun HotJava',
 'ibrowse','iBrowse',
@@ -220,34 +290,52 @@
 'jetaudio','JetAudio (media player)',
 'mint_audio','Mint Audio (media player)',
 'mpg123','mpg123 (media player)',
+'mplayer','The Movie Player (media player)',
 'nsplayer','NetShow Player (media player)',
+'qts','Quicktime',
 'sonique','Sonique (media player)',
 'uplayer','Ultra Player (media player)',
-'xmms','XMMS (media player)',
 'xaudio','Some XAudio Engine based MPEG player (media player)',
+'xine','Xine, a free multimedia player (media player)',
+'xmms','XMMS (media player)',
 # RSS Readers
+'abilon','Abilon (RSS Reader)',
 'aggrevator', 'Aggrevator (RSS Reader)',
+'akregator','<a href="http://akregator.sourceforge.net/" title="Browser home page [new window]" target="_blank">Akregator (RSS Reader)</a>',  
+'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank">AppleSyndication (RSS Reader)</a>',
+'betanews_reader','Betanews Reader (RSS Reader)',
+'blogbridge','<a href="http://www.blogbridge.com/" title="Browser home page [new window]" target="_blank">BlogBridge (RSS Reader)</a>',
 'feeddemon', 'FeedDemon (RSS Reader)',
 'feedreader', 'FeedReader (RSS Reader)',
-'jetbrains_omea_reader', 'Omea Reader (RSS Reader)',
+'feedtools','<a href="http://sporkmonger.com/projects/feedtools/" title="Browser home page [new window]" target="_blank">FeedTools (RSS Reader)</a>',
+'greatnews','<a href="http://www.curiostudio.com/" title="Browser home page [new window]" target="_blank">GreatNews (RSS Reader)</a>',
+'gregarius','<a href="http://devlog.gregarius.net/docs/ua" title="Browser home page [new window]" target="_blank">Gregarius (RSS Reader)</a>',
+'hatena_rss','<a href="http://r.hatena.ne.jp/" title="Browser home page [new window]" target="_blank">Hatena (RSS Reader)</a>',
+'jetbrains_omea', 'Omea (RSS Reader)',
+'liferea','<a href="http://liferea.sourceforge.net/" title="Browser home page [new window]" target="_blank">Liferea (RSS Reader)</a>',
+'lilina','<a href="http://lilina.sourceforge.net/" title="Browser home page [new window]" target="_blank">lilina (RSS Reader)</a>',
 'netnewswire', 'NetNewsWire (RSS Reader)',
 'newsfire', 'NewsFire (RSS Reader)',
 'newsgator', 'NewsGator (RSS Reader)',
 'newzcrawler', 'NewzCrawler (RSS Reader)',
 'pluck', 'Pluck (RSS Reader)',
+'potu_rss\-reader','<a href="http://www.potu.com/" title="Potu Rss-Reader home page [new window]" target="_blank">Potu (RSS Reader)</a>',
+'pubsub\-rss\-reader','<a href="http://www.pubsub.com/" title="Browser home page [new window]" target="_blank">PubSub (RSS Reader)</a>',
 'pulpfiction', 'PulpFiction (RSS Reader)',
 'rssbandit', 'RSS Bandit (RSS Reader)',
 'rssreader', 'RssReader (RSS Reader)',
 'rssowl', 'RSSOwl (RSS Reader)',
+'rss\sxpress','RSS Xpress (RSS Reader)',
+'rssxpress','RSSXpress (RSS Reader)',
 'sage', 'Sage (RSS Reader)',
 'sharpreader', 'SharpReader (RSS Reader)',
 'shrook', 'Shrook (RSS Reader)',
 'straw', 'Straw (RSS Reader)',
 'syndirella', 'Syndirella (RSS Reader)',
+'wizz\srss\snews\sreader','Wizz RSS News Reader (RSS Reader)',
 # PDA/Phonecell browsers
 'alcatel','Alcatel Browser (PDA/Phone browser)',
 'lg\-','LG (PDA/Phone browser)',
-'ericsson','Ericsson Browser (PDA/Phone browser)',
 'mot\-','Motorola Browser (PDA/Phone browser)',
 'nokia','Nokia Browser (PDA/Phone browser)',
 'panasonic','Panasonic Browser (PDA/Phone browser)',
@@ -257,6 +345,7 @@
 'sie\-','SIE (PDA/Phone browser)',
 'sec\-','Sony/Ericsson (PDA/Phone browser)',
 'sonyericsson','Sony/Ericsson Browser (PDA/Phone browser)',
+'ericsson','Ericsson Browser (PDA/Phone browser)',			# Must be after SonyEricsson
 'mmef','Microsoft Mobile Explorer (PDA/Phone browser)',
 'mspie','MS Pocket Internet Explorer (PDA/Phone browser)',
 'wapalizer','WAPalizer (PDA/Phone browser)',
@@ -268,18 +357,37 @@
 'portalmmm','I-Mode phone (PDA/Phone browser)',
 # Others (TV)
 'webtv','WebTV browser',
+# Anonymous Proxy Browsers (can be used as grabbers as well...)
+'cjb\.net','<a href="http://proxy.cjb.net/" title="Browser home page [new window]" target="_blank">CJB.NET Proxy</a>',
+'ossproxy','<a href="http://www.marketscore.com/FAQ.Aspx" title="OSSProxy home page [new window]" target="_blank">OSSProxy</a>',
 # Other kind of browsers
 'apt','Debian APT',
+'analogx_proxy','AnalogX Proxy',
+'gnome\-vfs', 'Gnome FileSystem Abstraction library', 
+'neon', 'Neon HTTP and WebDAV client library', 
 'curl','Curl',
 'csscheck','WDG CSS Validator',
+'httrack','HTTrack',
+'fdm','<a href="http://www.freedownloadmanager.org/" title="Browser home page [new window]" target="_blank">FDM Free Download Manager</a>',
 'javaws','Java Web Start',
 'wget','Wget',
+'chilkat', 'Chilkat',
+'webdownloader\sfor\sx','Downloader for X',
 'w3m','w3m',
 'wdg_validator','WDG HTML Validator',
+'webreaper','WebReaper',
 'webzip','WebZIP',
 'staroffice','StarOffice',
+'gnus', 'Gnus Network User Services',
+'nikto', 'Nikto Web Scanner', 
+'microsoft\-webdav\-miniredir', 'Microsoft Data Access Component Internet Publishing Provider',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager', 'Microsoft Data Access Component Internet Publishing Provider Cache Manager',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav', 'Microsoft Data Access Component Internet Publishing Provider DAV',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery', 'Microsoft Data Access Component Internet Publishing Provider Protocol Discovery',
+'POE\-Component\-Client\-HTTP','HTTP user-agent for POE (portable networking framework for Perl)',
 'mozilla','Mozilla',
 'libwww','LibWWW',
+'lwp','LibWWW-perl'
 );
 
 
@@ -292,7 +400,11 @@
 'webcapture','1',
 'webcopier','1',
 'curl','1',
+'fdm','1',
+'httrack','1',
+'webreaper','1',
 'wget','1',
+'webdownloader\sfor\sx','1',
 'webzip','1'
 );
 
@@ -306,7 +418,7 @@
 'msie','msie',
 'netscape','netscape',
 'firefox','firefox',
-
+'svn','subversion', 
 'firebird','phoenix',
 'go!zilla','gozilla',
 'icab','icab',
@@ -319,18 +431,24 @@
 'amigavoyager','amigavoyager',
 'avantbrowser','avant',
 'aweb','aweb',
+'bonecho','firefox',
 'bpftp','bpftp',
 'camino','chimera',
 'chimera','chimera',
 'cyberdog','cyberdog',
 'dillo','dillo',
+'doris','doris',
 'dreamcast','dreamcast',
+'xbox', 'winxbox',
 'ecatch','ecatch',
 'encompass','encompass',
 'epiphany','epiphany',
 'fresco','fresco',
 'galeon','galeon',
+'flashget','flashget',
+'freshdownload','freshdownload',
 'getright','getright',
+'leechget','leechget',
 'hotjava','hotjava',
 'ibrowse','ibrowse',
 'k\-meleon','kmeleon',
@@ -348,7 +466,7 @@
 'webcopier','webcopier',
 # Media only browsers
 'real','real',
-'winamp','winamp',				# Works for winampmpeg and winamp3httprdr
+'winamp','mediaplayer',				# Works for winampmpeg and winamp3httprdr
 'windows\-media\-player','mplayer',
 'audion','mediaplayer',
 'freeamp','mediaplayer',
@@ -356,11 +474,14 @@
 'jetaudio','mediaplayer',
 'mint_audio','mediaplayer',
 'mpg123','mediaplayer',
+'mplayer','mediaplayer',
 'nsplayer','netshow',
+'qts','mediaplayer',
 'sonique','mediaplayer',
 'uplayer','mediaplayer',
-'xmms','mediaplayer',
 'xaudio','mediaplayer',
+'xine','mediaplayer',
+'xmms','mediaplayer',
 # PDA/Phonecell browsers
 'alcatel','pdaphone',				# Alcatel
 'lg\-','pdaphone',                  # LG
@@ -385,30 +506,59 @@
 'portalmmm','pdaphone',
 # Others (TV)
 'webtv','webtv',
+# Anonymous Proxy Browsers (can be used as grabbers as well...)
+'cjb\.net','cjbnet',
+'ossproxy','ossproxy',
 # RSS Readers
+'abilon', 'abilon',
 'aggrevator', 'rss',
+'akregator', 'rss',
+'applesyndication', 'rss',
+'betanews_reader','rss',
+'blogbridge','rss',
 'feeddemon', 'rss',
 'feedreader', 'rss',
-'jetbrains_omea_reader', 'rss',
+'feedtools', 'rss',
+'greatnews', 'rss',
+'gregarius', 'rss',
+'hatena_rss', 'rss',
+'jetbrains_omea', 'rss',
+'liferea', 'rss',
+'lilina', 'rss',
 'netnewswire', 'rss',
 'newsfire', 'rss',
 'newsgator', 'rss',
 'newzcrawler', 'rss',
 'pluck', 'rss',
+'potu_rss\-reader', 'rss',
+'pubsub\-rss\-reader', 'rss',
 'pulpfiction', 'rss',
 'rssbandit', 'rss',
 'rssreader', 'rss',
 'rssowl', 'rss',
+'rss\sxpress','rss',
+'rssxpress','rss',
 'sage', 'rss',
 'sharpreader', 'rss',
 'shrook', 'rss',
 'straw', 'rss',
 'syndirella', 'rss',
+'wizz\srss\snews\sreader','wizz',
 # Other kind of browsers
 'apt','apt',
+'analogx_proxy','analogx',
+'microsoft\-webdav\-miniredir','frontpage',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager','frontpage',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav','frontpage',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery','frontpage',
+'gnome\-vfs', 'gnome', 
+'neon','neon', 
 'javaws','java',
 'webzip','webzip',
+'webreaper','webreaper',
+'httrack','httrack',
 'staroffice','staroffice',
+'gnus', 'gnus',
 'mozilla','mozilla'
 );
 
